@@ -1,7 +1,4 @@
 ## Reset logger threshold ##
 origLogThreshold <- as.numeric(Sys.getenv("PKGNET_TEST_ORIG_LOG_THRESHOLD"))
-futile.logger::flog.threshold(
-    threshold = origLogThreshold
-    , name = futile.logger::flog.namespace()
-)
+pkgnet:::.get_logger()$set_threshold(origLogThreshold)
 Sys.unsetenv("PKGNET_TEST_ORIG_LOG_THRESHOLD")
