@@ -12,4 +12,9 @@ test_that('Test packages installed correctly',{
             , info = sprintf("Test package %s is not installed.", thisTestPkg)
         )
     }
-})
\ No newline at end of file
+})
+
+# Record modifaction time of package directory to be checked at end of testing 
+# in test-Z-test-no-source-modifcations.R
+tmp_pkgnet_path <- file.path(Sys.getenv('PKGNET_TEST_LIB'), 'pkgnet')
+Sys.setenv(PKGNET_LATEST_MOD = as.character(file.info(tmp_pkgnet_path)$mtime))
\ No newline at end of file
