@@ -16,23 +16,23 @@ test_that('node coloring by discrete and continuous', {
         , palette = c("red", "green")
     )
 
-    expect_silent({
-
-        b$.__enclos_env__$private$set_plot_node_color_scheme(
-            field = "filename"
-            , palette = c(
-                "#E41A1C"
-                , "#377EB8"
-                , "#4DAF4A"
-                , "#984EA3"
-                , "#FF7F00"
-                , "#FFFF33"
-                , "#A65628"
-                , "#F781BF"
-                , "#999999"
-            )
-        )
-    })
+    #expect_silent({
+    #
+    #    b$.__enclos_env__$private$set_plot_node_color_scheme(
+    #        field = "filename"
+    #        , palette = c(
+    #            "#E41A1C"
+    #            , "#377EB8"
+    #            , "#4DAF4A"
+    #            , "#984EA3"
+    #            , "#FF7F00"
+    #            , "#FFFF33"
+    #            , "#A65628"
+    #            , "#F781BF"
+    #            , "#999999"
+    #        )
+    #    )
+    #})
 
     viz <- b$graph_viz
     expect_is(viz, "visNetwork")
